Module Co-ordinator: {{ coordinator.name }} ({{ coordinator.email }})

[[{{ course.title }} Question-Based Revision]]

## Course Components

{% set total_percentage = 0 %}
{% set weighted_achieved = 0 %}

{% for component, details in course.components.items() %}
- [{{ 'x' if details.current >= (0.7 * details.percentage) else ' ' }}] {{ component }} ({{ details.current | round(1) }}/ {{ details.percentage }}%)
  {% set total_percentage = total_percentage + details.percentage %}
  {% set weighted_achieved = weighted_achieved + details.current %}
{% endfor %}

*Current percentage:* {{ ((weighted_achieved / total_percentage) * 100) | round(0) }}% ({{ ((weighted_achieved / total_percentage) * 100) | round(1) }}%)

## Learning Outcomes

{% for outcome, completed in learning_outcomes.items() %}
- [{{ 'x' if completed else ' ' }}] {{ outcome }}
{% endfor %}

## Summary Content

[[{{ course.title }} Summary Notes]] - a comprehensive guide to solve any previously seen questions.
[[{{ course.title }} Summary Questions]] - a compilation of all questions from lectures, practicals, and assignments.
[[{{ course.title }} Practice Tests]] - a list of past, practice, and predicted papers; the latter generated by me.

## Flashcards

Optionally, you can take the most important flashcards from here and make them physical for more tactile revision.

[[{{ course.title }} Flashcards]] - a document full of flashcards to practice key definitions, theorems, and methods; includes an Anki deck of the same flashcards in .apkg format.

## Recommended Reading

{% for book in recommended_books %}
- **{{ book.title }}** by {{ book.author }} ({{ book.year }}) - Recommended for understanding {{ book.topics | join(", ") }}.
{% endfor %}

## Notes

{% for section in course.sections %}
### {{ section.title }}

{% for subsection in section.subsections %}
#### {{ subsection.title }}

{% for point in subsection.points %}
- **[[{{ point.link_title }}]]**: {{ point.description }}
{% endfor %}
{% endfor %}
{% endfor %}
